==> uos_hardware-0.4.0.tar.gz: uos_hardware-0.4.0/README.md <==
# ![NullTek Documentation](https://raw.githubusercontent.com/CreatingNull/NullTek-Assets/main/img/uos/UOSLogoSmall.png) UOS Hardware

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/uos-hardware?logo=python&logoColor=white)](https://pypi.org/project/uos-hardware/)
[![PyPI](https://img.shields.io/pypi/v/uos-hardware?logo=pypi&logoColor=white)](https://pypi.org/project/uos-hardware/#history)
[![Read the Docs](https://img.shields.io/readthedocs/uos-hardware?logo=readthedocs)](https://uos-hardware.nulltek.xyz)
[![License](https://img.shields.io/:license-mit-blue.svg)](https://github.com/CreatingNull/UOS-Hardware/blob/main/LICENSE.md)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/CreatingNull/UOS-Hardware/main.svg)](https://results.pre-commit.ci/latest/github/CreatingNull/UOS-Hardware/main)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/CreatingNull/uos-hardware/Tests?label=tests&logo=github)](https://github.com/CreatingNull/UOS-Hardware/actions/workflows/run-tests.yaml)

This repository contains a hardware abstraction layer for communicating with microcontrollers running UOS compliant firmware.

---

I just do this stuff for fun in my spare time, but feel free to:

[![Support via buymeacoffee](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/nulltek)

---

## License

The source of this repo uses the MIT open-source license, for details on the current licensing see [LICENSE](https://github.com/CreatingNull/UOS-Hardware/blob/main/LICENSE.md) or click the badge above.

==> uos_hardware-0.6.0.tar.gz: uos_hardware-0.6.0/README.md <==
# ![NullTek Documentation](https://raw.githubusercontent.com/CreatingNull/NullTek-Assets/main/img/uos/UOSLogoSmall.png) UOS Hardware

[![License](https://img.shields.io/:license-mit-blue.svg)](https://github.com/CreatingNull/UOS-Hardware/blob/main/LICENSE.md)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/uos-hardware?logo=python&logoColor=white)](https://pypi.org/project/uos-hardware/)
[![PyPI](https://img.shields.io/pypi/v/uos-hardware?logo=pypi&logoColor=white)](https://pypi.org/project/uos-hardware/#history)
[![Read the Docs](https://img.shields.io/readthedocs/uos-hardware?logo=readthedocs)](https://uos-hardware.nulltek.xyz)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/CreatingNull/UOS-Hardware/main.svg)](https://results.pre-commit.ci/latest/github/CreatingNull/UOS-Hardware/main)
[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/CreatingNull/uos-hardware/run-tests.yaml?branch=main&label=tests&logo=github)](https://github.com/CreatingNull/UOS-Hardware/actions/workflows/run-tests.yaml)

This repository contains a hardware abstraction layer for communicating with microcontrollers running UOS compliant firmware.

---

I just do this stuff for fun in my spare time, but feel free to:

[![Support via buymeacoffee](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/nulltek)

---

## License

The source of this repo uses the MIT open-source license, for details on the current licensing see [LICENSE](https://github.com/CreatingNull/UOS-Hardware/blob/main/LICENSE.md) or click the badge above.
